@@ -97,10 +97,10 @@ typedef struct {
 
     /* Forward declarations */
 extern int calmaWriteInitFunc(CellDef *def);
-extern int calmaWritePaintFunc(Tile *tile, calmaOutputStruct *cos);
-extern int calmaMergePaintFunc(Tile *tile, calmaOutputStruct *cos);
+extern int calmaWritePaintFunc(Tile *tile, TileType dinfo, calmaOutputStruct *cos);
+extern int calmaMergePaintFunc(Tile *tile, TileType dinfo, calmaOutputStruct *cos);
 extern int calmaWriteUseFunc(CellUse *use, FILE *f);
-extern int calmaPaintLabelFunc(Tile *tile, calmaOutputStruct *cos);
+extern int calmaPaintLabelFunc(Tile *tile, TileType dinfo, calmaOutputStruct *cos);
 extern void calmaWriteContacts(FILE *f);
 extern void calmaDelContacts(void);
 extern void calmaOutFunc(CellDef *def, FILE *f, const Rect *cliprect);
@@ -2464,6 +2464,7 @@ calmaProcessBoundary(
 int
 calmaMergePaintFunc(
     Tile *tile,			/* Tile to be written out. */
+    TileType dinfo,		/* Split tile information (unused) */
     calmaOutputStruct *cos)	/* Information needed by algorithm */
 {
     FILE *f = cos->f;
@@ -2494,11 +2495,10 @@ calmaMergePaintFunc(
 	split_type = -1;
 	if (IsSplit(t))
 	{
-	    /* If we use SplitSide, then we need to set it when	the	*/
+	    /* If we use TT_SIDE, then we need to set it when the	*/
 	    /* tile is pushed.  Since these are one-or-zero mask layers	*/
 	    /* I assume it is okay to just check which side is TT_SPACE	*/
 
-	    /* split_type = (SplitSide(t) << 1) | SplitDirection(t); */
 	    split_type = SplitDirection(t);
 	    if (TiGetLeftType(t) == TT_SPACE) split_type |= 2;
 	    num_points = 2;
@@ -2721,7 +2721,9 @@ right_search:
 done_searches:
 	if (intedges == 0)
 	{
-	    calmaWritePaintFunc(t, cos);
+	    calmaWritePaintFunc(t,
+			(split_type & 2) ? (TileType)TT_SIDE : (TileType)0,
+			cos);
 
 	    /* Although calmaWritePaintFunc is called only on isolated	*/
 	    /* tiles, we may have expanded it.  This could use a LOT of	*/
@@ -2791,6 +2793,7 @@ done_searches:
 int
 calmaWritePaintFunc(
     Tile *tile,			/* Tile to be written out. */
+    TileType dinfo,		/* Split tile information */
     calmaOutputStruct *cos)	/* File for output and clipping area */
 {
     FILE *f = cos->f;
@@ -2826,7 +2829,7 @@ calmaWritePaintFunc(
 	/* Coordinates */
 	calmaOutRH(36, CALMA_XY, CALMA_I4, f);
 
-	switch ((SplitSide(tile) << 1) | SplitDirection(tile))
+	switch (((dinfo & TT_SIDE) ? 2 : 0) | SplitDirection(tile))
 	{
 	    case 0x0:
 		calmaOutI4(r.r_xbot, f); calmaOutI4(r.r_ybot, f);
@@ -3067,6 +3070,7 @@ calmaWriteLabelFunc(
 int
 calmaPaintLabelFunc(
     Tile *tile,			/* Tile contains area for label. */
+    TileType dinfo,		/* Split tile information (unused) */
     calmaOutputStruct *cos)	/* File for output and clipping area */
 {
     FILE *f = cos->f;
