@@ -158,8 +158,9 @@ drcFindOtherCells(use, dlu)
  */
 
 int
-drcSubCopyErrors(tile, cxp)
+drcSubCopyErrors(tile, dinfo, cxp)
     Tile *tile;
+    TileType dinfo;		/* (unused) */
     TreeContext *cxp;
 {
     Rect area;
@@ -317,7 +318,9 @@ drcSubcellFunc(subUse, dsa)
  */
 
 int
-drcAlwaysOne()
+drcAlwaysOne(Tile *tile,
+    TileType dinfo,
+    ClientData clientdata)
 {
     return 1;
 }
@@ -419,7 +422,6 @@ DRCFindInteractions(def, area, radius, interaction)
     CellUse *use;
     SearchContext scx;
     Rect searchArea, intArea;
-    int flags;
     struct drcSubcellArg dsa;
     struct drcLinkedUse *curDLU;
 
@@ -492,24 +494,21 @@ DRCFindInteractions(def, area, radius, interaction)
     /* If errors are being propagated up from child to parent,	*/
     /* then the interaction area is always valid.		*/
 
-    if (!(flags & PROPAGATE_FLAG))
+    for (i = PL_TECHDEPBASE; i < DBNumPlanes; i++)
     {
-	for (i = PL_TECHDEPBASE; i < DBNumPlanes; i++)
+	if (DBSrPaintArea((Tile *) NULL, def->cd_planes[i],
+		&intArea, &DBAllButSpaceBits, drcAlwaysOne,
+		(ClientData) NULL) != 0)
 	{
-	    if (DBSrPaintArea((Tile *) NULL, def->cd_planes[i],
-			&intArea, &DBAllButSpaceBits, drcAlwaysOne,
-			(ClientData) NULL) != 0)
-	    {
-		use = (CellUse *) -1;
-		break;
-	    }
+	    use = (CellUse *) -1;
+	    break;
 	}
-	scx.scx_use = DRCDummyUse;
-	scx.scx_trans = GeoIdentityTransform;
-	scx.scx_area = intArea;
-	if (DBTreeSrCells(&scx, 0, drcSubCheckPaint, (ClientData) &use) == 0)
-	    return 0;
     }
+    scx.scx_use = DRCDummyUse;
+    scx.scx_trans = GeoIdentityTransform;
+    scx.scx_area = intArea;
+    if (DBTreeSrCells(&scx, 0, drcSubCheckPaint, (ClientData) &use) == 0)
+	return 0;
 
     /* OK, no more excuses, there's really an interaction area here. */
 
@@ -540,8 +539,9 @@ DRCFindInteractions(def, area, radius, interaction)
  */
 
 int
-drcExactOverlapCheck(tile, arg)
+drcExactOverlapCheck(tile, dinfo, arg)
     Tile *tile;			/* Tile to check. */
+    TileType dinfo;		/* Split tile information (unused) */
     struct drcClientData *arg;	/* How to detect and process errors. */
 {
     Rect rect;
@@ -579,8 +579,9 @@ drcExactOverlapCheck(tile, arg)
  */
 
 int
-drcExactOverlapTile(tile, cxp)
+drcExactOverlapTile(tile, dinfo, cxp)
     Tile *tile;			/* Tile that must overlap exactly. */
+    TileType dinfo;		/* Split tile information (unused) */
     TreeContext *cxp;		/* Tells how to translate out of subcell.
 				 * The client data must be a drcClientData
 				 * record, and the caller must have filled
