@@ -3,8 +3,8 @@
  *	Definitions for ext2spice.c and ext2hier.c
  */
 
-#ifndef _EXTTOSPICE_H
-#define _EXTTOSPICE_H
+#ifndef _MAGIC__EXT2SPICE__EXT2SPICE_H
+#define _MAGIC__EXT2SPICE__EXT2SPICE_H
 
 /* cache list used to find parallel devs */
 typedef struct _devMerge {
@@ -13,46 +13,50 @@ typedef struct _devMerge {
 	Dev * dev;
 	int	  esFMIndex;
 	HierName *hierName;
-	struct _devMerge *next;
+	const struct _devMerge *next;
 } devMerge;
 
+#include "extflat/EFint.h" /* HierContext */
+
 /* Forward declarations */
-void CmdExtToSpice();
-extern int spcParseArgs();
-extern int spccapVisit(), spcdevVisit(), spcnodeVisit(), subcktVisit();
-extern int spcresistVisit(), devMergeVisit(), devDistJunctVisit();
-extern int spcsubVisit();
-extern int subcktUndef();
-extern EFNode *spcdevSubstrate();
-extern char *nodeSpiceName();
-extern int nodeVisitDebug();
-extern void topVisit();
-extern void swapDrainSource();
-extern int _ext2spice_start();
+extern void CmdExtToSpice(MagWindow *w, TxCommand *cmd);
+extern int spcParseArgs(int *pargc, char ***pargv);
+extern int spccapVisit(HierName *hierName1, HierName *hierName2, double cap, ClientData cdata); /* @typedef cb_extflat_visitcaps_t (UNUSED) */
+extern int spcdevVisit(Dev *dev, HierContext *hc, float scale, Transform *trans, ClientData cdata); /* @typedef cb_extflat_visitdevs_t (UNUSED) */
+extern int spcnodeVisit(EFNode *node, int res, double cap, ClientData cdata); /* @typedef cb_extflat_visitnodes_t (UNUSED) */
+extern int subcktVisit(Use *use, HierName *hierName, bool is_top); /* @typedef cb_extflat_visitsubcircuits_t */
+extern int spcresistVisit(const HierName *hierName1, const HierName *hierName2, float res,  ClientData cdata); /* @typedef cb_extflat_visitresists_t (UNUSED) */
+extern int devMergeVisit(Dev *dev, HierContext *hc, float scale, Transform *trans, ClientData cdata); /* @typedef cb_extflat_visitdevs_t (UNUSED) */
+extern int devDistJunctVisit(Dev *dev, HierContext *hc, float scale, Transform *trans, ClientData cdata); /* @typedef cb_extflat_visitdevs_t (UNUSED) */
+extern int spcsubVisit(EFNode *node, int res, double cap, ClientData cdata); /* @typedef cb_extflat_visitnodes_t (char** resstr) */
+extern int subcktUndef(Use *use, HierName *hierName, bool is_top); /* @typedef cb_extflat_visitsubcircuits_t */
+extern EFNode *spcdevSubstrate(HierName *prefix, HierName *suffix, int type, FILE *outf);
+extern const char *nodeSpiceName(const HierName *hname, EFNode **rnode);
+extern int nodeVisitDebug(EFNode *node, int res, double cap, ClientData cdata); /* @typedef cb_extflat_visitnodes_t (UNUSED) */
+extern void topVisit(Def *def, bool doStub);
+extern void swapDrainSource(Dev *dev);
 
-extern EFNode *spcdevHierSubstrate();
-extern char *nodeSpiceHierName();
-extern devMerge *mkDevMerge();
-extern bool extHierSDAttr();
-extern int esFreeNodeClient();
+extern const char *nodeSpiceHierName(HierContext *hc, const HierName *hname);
+extern devMerge *mkDevMerge(float l, float w, EFNode *g, EFNode *s, EFNode *d, EFNode *b, HierName *hn, Dev *dev);
+extern bool extHierSDAttr(DevTerm *term);
 
-extern bool devIsKilled();
-extern float getCurDevMult();
-extern void addDevMult();
-extern void setDevMult();
+extern bool devIsKilled(int n);
+extern float getCurDevMult(void);
+extern void addDevMult(float f);
+extern void setDevMult(int i, float f);
 
 /* C99 compat */
-extern int  EFHNSprintf();
-extern int  printSubcktDict();
-extern int  spcdevOutNode();
-extern int  spcnAP();
-extern int  parallelDevs();
-extern int  nodeHspiceName();
-extern int  devDistJunctHierVisit();
-extern int  spcnAPHier();
-extern void mergeAttr();
-extern int  update_w();
-extern void esSIvalue();
+extern int EFHNSprintf(char *str, HierName *hierName);
+extern int printSubcktDict(void);
+extern int spcdevOutNode(const HierName *prefix, const HierName *suffix, const char *name, FILE *outf);
+extern int spcnAP(DevTerm *dterm, EFNode *node, int resClass, float scale, char *asterm, char *psterm, float m, FILE *outf, int w);
+extern int parallelDevs(const devMerge *f1, const devMerge *f2);
+extern int nodeHspiceName(char *s);
+extern int devDistJunctHierVisit(HierContext *hc, Dev *dev, float scale, ClientData cdata); /* @typedef cb_extflat_hiervisitdevs_t (UNUSED) */
+extern int spcnAPHier(DevTerm *dterm, HierName *hierName, int resClass, float scale, char *asterm, char *psterm, float m, FILE *outf);
+extern void mergeAttr(char **a1, char **a2);
+extern int update_w(short resClass, int w, EFNode *n);
+extern void esSIvalue(FILE *file, float value);
 
 /* Options specific to ext2spice */
 extern bool esDoExtResis;
@@ -65,8 +69,8 @@ extern bool esDevNodesOnly;
 extern bool esNoAttrs;
 extern bool esHierAP;
 extern char spcesDefaultOut[FNSIZE];
-extern char *esSpiceCapNode;
-extern char esSpiceDefaultGnd[];
+extern const char *esSpiceCapNode;
+extern const char esSpiceDefaultGnd[];
 extern char *spcesOutName;
 extern FILE *esSpiceF;
 extern float esScale;	/* negative if hspice the EFScale/100 otherwise */
@@ -74,7 +78,11 @@ extern float esScale;	/* negative if hspice the EFScale/100 otherwise */
 extern unsigned short esFormat;
 extern TileTypeBitMask initMask;
 
-extern int esCapNum, esDevNum, esResNum, esDiodeNum, esVoltNum;
+extern int esCapNum;
+extern int esDevNum;
+extern int esResNum;
+extern int esDiodeNum;
+extern int esVoltNum;
 extern int esNodeNum;  /* just in case we're extracting spice2 */
 extern int esSbckNum; 	/* used in hspice node name shortening   */
 extern int esNoModelType;  /* index for device type "None" (model-less device) */
@@ -89,7 +97,7 @@ extern int	 esFMIndex;     /* current index to it */
 extern int	 esFMSize; 	/* its current size (growable) */
 
 extern int	 esSpiceDevsMerged;
-extern devMerge *devMergeList;
+extern const devMerge *devMergeList;
 
 /*
  * The following hash table and associated functions are used only if
@@ -165,6 +173,7 @@ typedef struct {
 #define	SPICE3	1
 #define	HSPICE	2
 #define	NGSPICE	3
+#define	CDL	4
 
 #define AUTO	2	/* TRUE | FALSE | AUTO for esDoSubckt */
 
@@ -188,4 +197,6 @@ typedef struct {
 #define 	atoCap(s)	((EFCapValue)atof(s))
 #endif
 
-#endif  /* _EXTTOSPICE_H */
+extern int esFreeNodeClient(nodeClient *client);
+
+#endif  /* _MAGIC__EXT2SPICE__EXT2SPICE_H */
