@@ -713,14 +713,15 @@ extArrayNodeName(np, ha, et1, et2)
     ExtTree *et1, *et2;
 {
     Tile *tp;
+    TileType dinfo;
 
-    tp = extNodeToTile(np, et1);
-    if (tp && TiGetType(tp) != TT_SPACE && extHasRegion(tp, extUnInit))
-	return (extArrayTileToNode(tp, np->nreg_pnum, et1, ha, TRUE));
+    tp = extNodeToTile(np, et1, &dinfo);
+    if (tp && TiGetType(tp) != TT_SPACE && extHasRegion(tp, CLIENTDEFAULT))
+	return (extArrayTileToNode(tp, dinfo, np->nreg_pnum, et1, ha, TRUE));
 
-    tp = extNodeToTile(np, et2);
-    if (tp && TiGetType(tp) != TT_SPACE && extHasRegion(tp, extUnInit))
-	return (extArrayTileToNode(tp, np->nreg_pnum, et2, ha, TRUE));
+    tp = extNodeToTile(np, et2, &dinfo);
+    if (tp && TiGetType(tp) != TT_SPACE && extHasRegion(tp, CLIENTDEFAULT))
+	return (extArrayTileToNode(tp, dinfo, np->nreg_pnum, et2, ha, TRUE));
 
     return ("(none)");
 }
@@ -768,8 +769,9 @@ extArrayNodeName(np, ha, et1, et2)
  */
 
 char *
-extArrayTileToNode(tp, pNum, et, ha, doHard)
+extArrayTileToNode(tp, dinfo, pNum, et, ha, doHard)
     Tile *tp;
+    TileType dinfo;
     int pNum;
     ExtTree *et;
     HierExtractArg *ha;
@@ -791,15 +793,15 @@ extArrayTileToNode(tp, pNum, et, ha, doHard)
     LabRegion *reg;
     Rect r;
 
-    if (extHasRegion(tp, extUnInit))
+    if (extHasRegion(tp, CLIENTDEFAULT))
     {
-	reg = (LabRegion *) extGetRegion(tp);
+	reg = (LabRegion *) ExtGetRegion(tp, dinfo);
 	if (reg->lreg_labels)
 	    goto found;
     }
 
     if (!DebugIsSet(extDebugID, extDebNoHard))
-	if ((reg = (LabRegion *) extArrayHardNode(tp, pNum, def, ha)))
+	if ((reg = (LabRegion *) extArrayHardNode(tp, dinfo, pNum, def, ha)))
 	    goto found;
 
     /* Blew it */
@@ -934,17 +936,23 @@ extArrayRange(dstp, lo, hi, prevRange, followRange)
  */
 
 LabRegion *
-extArrayHardNode(tp, pNum, def, ha)
+extArrayHardNode(tp, dinfo, pNum, def, ha)
     Tile *tp;
+    TileType dinfo;
     int pNum;
     CellDef *def;
     HierExtractArg *ha;
 {
-    TileType type = TiGetType(tp);
+    TileType type;
     char labelBuf[4096];
     SearchContext scx;
     HardWay arg;
 
+    if (IsSplit(tp))
+	type = (dinfo & TT_SIDE) ? TiGetRightType(tp) : TiGetLeftType(tp);
+    else
+	type = TiGetType(tp);
+
     arg.hw_ha = ha;
     arg.hw_label = (Label *) NULL;
     arg.hw_mask = DBPlaneTypes[pNum];
@@ -971,7 +979,7 @@ extArrayHardNode(tp, pNum, def, ha)
 	LabRegion *lreg;
 	LabelList *ll;
 
-	lreg = (LabRegion *) extGetRegion(tp);
+	lreg = (LabRegion *) ExtGetRegion(tp, dinfo);
 	ll = (LabelList *) mallocMagic((unsigned) (sizeof (LabelList)));
 	lreg->lreg_labels = ll;
 	ll->ll_next = (LabelList *) NULL;
