@@ -197,6 +197,7 @@ extSubtree(parentUse, reg, f)
     ha.ha_parentUse = parentUse;
     ha.ha_parentReg = reg;
     ha.ha_nodename = extSubtreeTileToNode;
+    ha.ha_interArea = GeoNullRect;
     ha.ha_cumFlat.et_use = extYuseCum;
     HashInit(&ha.ha_connHash, 32, 0);
 
@@ -345,8 +346,9 @@ done:
 
 #ifdef	exactinteractions
 int
-extSubtreeCopyPlane(tile, plane)
+extSubtreeCopyPlane(tile, dinfo, plane)
     Tile *tile;
+    TileType dinfo;
     Plane *plane;
 {
     Rect r;
@@ -358,8 +360,9 @@ extSubtreeCopyPlane(tile, plane)
 }
 
 int
-extSubtreeShrinkPlane(tile, plane)
+extSubtreeShrinkPlane(tile, dinfo, plane)
     Tile *tile;
+    TileType dinfo;
     Plane *plane;
 {
     Rect r;
@@ -374,8 +377,9 @@ extSubtreeShrinkPlane(tile, plane)
 }
 
 int
-extSubtreeInterFunc(tile, ha)
+extSubtreeInterFunc(tile, dinfo, ha)
     Tile *tile;
+    TileType dinfo;
     HierExtractArg *ha;
 {
     TITORECT(tile, &ha->ha_interArea);
@@ -684,18 +688,22 @@ extSubtreeOutputCoupling(ha)
     HashStartSearch(&hs);
     while ((he = HashNext(&ha->ha_cumFlat.et_coupleHash, &hs)))
     {
+	TileType dinfo;
+
 	cap = extGetCapValue(he) / ExtCurStyle->exts_capScale;
 	if (cap == 0)
 	    continue;
 
 	ck = (CoupleKey *) he->h_key.h_words;
 
-	tp = extNodeToTile(ck->ck_1, &ha->ha_cumFlat);
-	name = extSubtreeTileToNode(tp, ck->ck_1->nreg_pnum, &ha->ha_cumFlat, ha, TRUE);
+	tp = extNodeToTile(ck->ck_1, &ha->ha_cumFlat, &dinfo);
+	name = extSubtreeTileToNode(tp, dinfo, ck->ck_1->nreg_pnum,
+			&ha->ha_cumFlat, ha, TRUE);
 	fprintf(ha->ha_outf, "cap \"%s\" ", name);
 
-	tp = extNodeToTile(ck->ck_2, &ha->ha_cumFlat);
-	name = extSubtreeTileToNode(tp, ck->ck_2->nreg_pnum, &ha->ha_cumFlat, ha, TRUE);
+	tp = extNodeToTile(ck->ck_2, &ha->ha_cumFlat, &dinfo);
+	name = extSubtreeTileToNode(tp, dinfo, ck->ck_2->nreg_pnum,
+			&ha->ha_cumFlat, ha, TRUE);
 	fprintf(ha->ha_outf, "\"%s\" %lg\n", name, cap);
     }
 }
@@ -713,8 +721,9 @@ extSubtreeOutputCoupling(ha)
  */
 
 int
-extFoundProc(tile, clientData)
+extFoundProc(tile, dinfo, clientData)
     Tile *tile;
+    TileType dinfo;
     ClientData clientData;
 {
     return 1;
@@ -882,7 +891,7 @@ extSubtreeFunc(scx, ha)
 	    (NodeRegion *) ExtFindRegions(cumUse->cu_def, &TiPlaneRect,
 				&ExtCurStyle->exts_activeTypes,
 				ExtCurStyle->exts_nodeConn,
-				extUnInit, extHierLabFirst, (int (*)()) NULL);
+				extHierLabFirst, (int (*)()) NULL);
 	ExtLabelRegions(cumUse->cu_def, ExtCurStyle->exts_nodeConn,
 			&(ha->ha_cumFlat.et_nodes), &TiPlaneRect);
     }
@@ -919,7 +928,7 @@ extSubtreeFunc(scx, ha)
     /* Free the cumulative node list we extracted above */
     if (ha->ha_cumFlat.et_nodes)
     {
-	ExtResetTiles(cumUse->cu_def, extUnInit);
+	ExtResetTiles(cumUse->cu_def, CLIENTDEFAULT);
 	ExtFreeLabRegions((LabRegion *) ha->ha_cumFlat.et_nodes);
 	ha->ha_cumFlat.et_nodes = (NodeRegion *) NULL;
     }
@@ -1040,9 +1049,10 @@ extSubstrateFunc(scx, ha)
  */
 
 char *
-extSubtreeTileToNode(tp, pNum, et, ha, doHard)
-    Tile *tp;	/* Tile whose node name is to be found */
-    int pNum;	/* Plane of the tile */
+extSubtreeTileToNode(tp, dinfo, pNum, et, ha, doHard)
+    Tile *tp;		/* Tile whose node name is to be found */
+    TileType dinfo;	/* Split tile information */
+    int pNum;		/* Plane of the tile */
     ExtTree *et;	/* Yank buffer to search */
     HierExtractArg *ha;	/* Extraction context */
     bool doHard;	/* If TRUE, we look up this node's name the hard way
@@ -1061,9 +1071,9 @@ extSubtreeTileToNode(tp, pNum, et, ha, doHard)
     TileType ttype;
 
     /* If there is a label list, use it */
-    if (extHasRegion(tp, extUnInit))
+    if (extHasRegion(tp, CLIENTDEFAULT))
     {
-	reg = (LabRegion *) extGetRegion(tp);
+	reg = (LabRegion *) ExtGetRegion(tp, dinfo);
 	if (reg->lreg_labels)
 	    return (extNodeName(reg));
     }
@@ -1080,12 +1090,7 @@ extSubtreeTileToNode(tp, pNum, et, ha, doHard)
 	 * can cause problems.
 	 */
 	if (IsSplit(tp))
-	{
-	    if (SplitSide(tp))
-		ttype = SplitRightType(tp);
-	    else
-		ttype = SplitLeftType(tp);
-	}
+	    ttype = (dinfo & TT_SIDE) ? SplitRightType(tp) : SplitLeftType(tp);
 	else
 	    ttype = TiGetTypeExact(tp);
 
@@ -1095,7 +1100,7 @@ extSubtreeTileToNode(tp, pNum, et, ha, doHard)
 	    {
 		if (DBSrPaintNMArea((Tile *) NULL,
 			et->et_lookNames->cd_planes[pNum],
-			TiGetTypeExact(tp), &r, &DBAllButSpaceBits,
+			TiGetTypeExact(tp) | dinfo, &r, &DBAllButSpaceBits,
 			extConnFindFunc, (ClientData) &reg))
 		{
 		    if (SigInterruptPending)
@@ -1119,8 +1124,8 @@ extSubtreeTileToNode(tp, pNum, et, ha, doHard)
 
     /* We have to do it the hard way */
     if (!doHard) return ((char *) NULL);
-    if (extHasRegion(tp, extUnInit)
-	    && (reg = extSubtreeHardNode(tp, pNum, et, ha)))
+    if (extHasRegion(tp, CLIENTDEFAULT)
+	    && (reg = extSubtreeHardNode(tp, dinfo, pNum, et, ha)))
     {
 	if (ExtDoWarn & EXTWARN_LABELS)
 	{
@@ -1154,13 +1159,14 @@ extSubtreeTileToNode(tp, pNum, et, ha, doHard)
  */
 
 int
-extConnFindFunc(tp, preg)
+extConnFindFunc(tp, dinfo, preg)
     Tile *tp;
+    TileType dinfo;	// Unused, but needs to be handled
     LabRegion **preg;
 {
-    if (extHasRegion(tp, extUnInit))
+    if (extHasRegion(tp, CLIENTDEFAULT))
     {
-	*preg = (LabRegion *) extGetRegion(tp);
+	*preg = (LabRegion *)ExtGetRegion(tp, dinfo);
 	return (1);
     }
 
@@ -1198,13 +1204,14 @@ extConnFindFunc(tp, preg)
  */
 
 LabRegion *
-extSubtreeHardNode(tp, pNum, et, ha)
+extSubtreeHardNode(tp, dinfo, pNum, et, ha)
     Tile *tp;
+    TileType dinfo;
     int pNum;
     ExtTree *et;
     HierExtractArg *ha;
 {
-    LabRegion *lreg = (LabRegion *) extGetRegion(tp);
+    LabRegion *lreg = (LabRegion *) ExtGetRegion(tp, dinfo);
     CellDef *def = et->et_use->cu_def;
     TileType ttype;
     char labelBuf[4096];
@@ -1215,7 +1222,7 @@ extSubtreeHardNode(tp, pNum, et, ha)
 
     if (IsSplit(tp))
     {
-	if (SplitSide(tp))
+	if (dinfo & TT_SIDE)
 	    ttype = SplitRightType(tp);
 	else
 	    ttype = SplitLeftType(tp);
