@@ -358,8 +358,8 @@ extTimesCellFunc(cs)
     /* Count the number of transistors */
     transList = (TransRegion *) ExtFindRegions(def, &TiPlaneRect,
 		    &ExtCurStyle->exts_deviceMask, ExtCurStyle->exts_deviceConn,
-		    extUnInit, extTransFirst, extTransEach);
-    ExtResetTiles(def, extUnInit);
+		    extTransFirst, extTransEach);
+    ExtResetTiles(def, CLIENTDEFAULT);
     for (tl = transList; tl; tl = tl->treg_next)
 	cs->cs_fets++;
     ExtFreeLabRegions((LabRegion *) transList);
@@ -396,8 +396,9 @@ extTimesCellFunc(cs)
  */
 
 int
-extCountTiles(tile, cs)
-    Tile *tile;			/* UNUSED */
+extCountTiles(tile, dinfo, cs)
+    Tile *tile;			/* (unused) */
+    TileType dinfo;		/* (unused) */
     struct cellStats *cs;
 {
     cs->cs_rects++;
@@ -843,7 +844,7 @@ extPaintOnly(def)
 
     reg = extBasic(def, extDevNull);
     if (reg) ExtFreeLabRegions((LabRegion *) reg);
-    ExtResetTiles(def, extUnInit);
+    ExtResetTiles(def, CLIENTDEFAULT);
 }
 
 /*
@@ -1115,8 +1116,9 @@ extInterAreaFunc(use, f)
 }
 
 int
-extInterCountFunc(tile, pArea)
+extInterCountFunc(tile, dinfo, pArea)
     Tile *tile;
+    TileType dinfo;	/* (unused) */
     int *pArea;
 {
     Rect r;
