@@ -58,6 +58,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 #define		DEV_NAME		2
 #define		DEV_X			3
 #define		DEV_Y			4
+#define		DEV_PARAM_START		7
 
 #define		NODES_NODENAME		1
 #define		NODES_NODEX		4
@@ -83,8 +84,6 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 
 #define MAXDIGIT		20
 
-ResExtNode	*ResInitializeNode();
-
 ResExtNode	*ResOriginalNodes;	/*Linked List of Nodes 	*/
 char		RDEV_NOATTR[1] = {'0'};
 ResFixPoint	*ResFixList;
@@ -102,7 +101,7 @@ ResFixPoint	*ResFixList;
  */
 
 int
-ResReadExt(char *extfile)
+ResReadExt(CellDef *def)
 {
     char *line = NULL, *argv[128];
     int	result, locresult;
@@ -111,31 +110,12 @@ ResReadExt(char *extfile)
     CellDef *dbdef;
     ResExtNode *curnode;
 
-    /* Search for the .ext fie in the same way that efReadDef() does. */
-
-    fp = PaOpen(extfile, "r", ".ext", EFSearchPath, EFLibPath, (char **)NULL);
-    if ((fp == NULL) && ((dbdef = DBCellLookDef(extfile)) != NULL)
-			&& (dbdef->cd_file != NULL))
-    {
-	char *filepath, *sptr;
-
-	filepath = StrDup((char **)NULL, dbdef->cd_file);
-	sptr = strrchr(filepath, '/');
-	if (sptr)
-	{
-	    *sptr = '\0';
-	    fp = PaOpen(extfile, "r", ".ext", filepath, EFLibPath, (char **)NULL);
-	}
-	freeMagic(filepath);
-    }
-
-    /* Try with the standard search path */
-    if ((fp == NULL) && (EFSearchPath == NULL))
-	fp = PaOpen(extfile, "r", ".ext", Path, EFLibPath, (char **)NULL);
+    /* Search for the .ext file in the same way that efReadDef() does. */
 
+    fp = ExtFileOpen(def, (char *)NULL, "r", (char **)NULL);
     if (fp == NULL)
     {
-    	TxError("Cannot open file %s%s\n", extfile, ".ext");
+    	TxError("Cannot open file %s%s\n", def->cd_name, ".ext");
 	return 1;
     }
 
@@ -220,11 +200,17 @@ ResReadNode(int argc, char *argv[])
     ResExtNode	*node;
 
     entry = HashFind(&ResNodeTable, argv[NODES_NODENAME]);
-    node = ResInitializeNode(entry);
+    node = ResExtInitNode(entry);
 
-    node->location.p_x = atoi(argv[NODES_NODEX]);
-    node->location.p_y = atoi(argv[NODES_NODEY]);
-    node->type = DBTechNameType(argv[NODES_NODETYPE]);
+    /* If this node was previously read as a port, then don't change the
+     * location.
+     */
+    if (!(node->status & PORTNODE))
+    {
+	node->location.p_x = atoi(argv[NODES_NODEX]);
+	node->location.p_y = atoi(argv[NODES_NODEY]);
+	node->type = DBTechNameType(argv[NODES_NODETYPE]);
+    }
 
     if (node->type == -1)
     {
@@ -255,7 +241,7 @@ ResReadPort(int argc,
     ResExtNode	*node;
 
     entry = HashFind(&ResNodeTable, argv[PORT_NAME]);
-    node = ResInitializeNode(entry);
+    node = ResExtInitNode(entry);
 
     node->drivepoint.p_x = atoi(argv[PORT_LLX]);
     node->drivepoint.p_y = atoi(argv[PORT_LLY]);
@@ -335,11 +321,11 @@ ResReadDevice(int argc,
     TileType	ttype;
     HashEntry	*entry;
     ResExtNode	*node;
+    ResValue	rpersquare;
+    float	wval;
 
     device = (RDev *)mallocMagic((unsigned)(sizeof(RDev)));
 
-    device->resistance = 0;	/* Linear resistance from FET line, unused */
-
     device->status = FALSE;
     device->nextDev = ResRDevList;
 
@@ -365,10 +351,25 @@ ResReadDevice(int argc,
     device->drain = (ResExtNode *)NULL;
     device->subs = (ResExtNode *)NULL;
 
-    /* Pass over parameters and find the next argument */
+    entry = HashLookOnly(&devptr->exts_deviceResist, "linear");
+    if (entry != NULL)
+	rpersquare = (ResValue)(spointertype)HashGetValue(entry);
+    else
+	rpersquare = (ResValue)10000.0;		/* Default to a sane value */
+
+    /* For devices, the device width is in the parameter list */
+    wval = 0.0;
     for (i = DEV_Y; i < argc; i++)
-	if (!StrIsInt(argv[i]) && !(strchr(argv[i], '=')))
+    {
+	char *eptr;
+	if ((eptr = strchr(argv[i], '=')) != NULL)
+	{
+	    if (*argv[i] == 'w')
+		sscanf(eptr + 1, "%f", &wval);
+	}
+	else if (!StrIsInt(argv[i]))
 	    break;
+    }
 
     if (i == argc)
     {
@@ -376,6 +377,8 @@ ResReadDevice(int argc,
 		argv[DEV_NAME]);
 	return 1;
     }
+    else
+	device->resistance = wval * rpersquare;	/* Channel resistance */
 
     /* Find and record the device terminal nodes */
     /* Note that this only records up to two terminals matching FET
@@ -448,11 +451,11 @@ ResReadFET(int argc,
     TileType	ttype;
     HashEntry	*entry;
     ResExtNode	*node;
+    ResValue	rpersquare;
+    float	area, perim, wval, lval;
 
     device = (RDev *)mallocMagic((unsigned)(sizeof(RDev)));
 
-    device->resistance = 0;	/* Linear resistance from FET line, unused */
-
     device->status = FALSE;
     device->nextDev = ResRDevList;
 
@@ -469,11 +472,25 @@ ResReadFET(int argc,
     device->location.p_x = atoi(argv[FET_X]);
     device->location.p_y = atoi(argv[FET_Y]);
 
-    device->rs_gattr=RDEV_NOATTR;
-    device->rs_sattr=RDEV_NOATTR;
-    device->rs_dattr=RDEV_NOATTR;
+    device->rs_gattr = RDEV_NOATTR;
+    device->rs_sattr = RDEV_NOATTR;
+    device->rs_dattr = RDEV_NOATTR;
     device->rs_devptr = devptr;
 
+    entry = HashLookOnly(&devptr->exts_deviceResist, "linear");
+    if (entry != NULL)
+	rpersquare = (ResValue)(spointertype)HashGetValue(entry);
+    else
+	rpersquare = (ResValue)10000.0;		/* Default to a sane value */
+
+    /* For old-style FETs, the width is determined from area and perimeter */ 
+    area = MagAtof(argv[FET_AREA]);
+    perim = MagAtof(argv[FET_PERIM]);
+    lval = 0.5 * (perim + sqrt(perim * perim - 4 * area));
+    wval = area / lval;
+
+    device->resistance = wval * rpersquare;	/* Channel resistance */
+
     /* Find and record the FET terminal nodes */
 
     entry = HashFind(&ResNodeTable, argv[FET_GATE]);
@@ -523,19 +540,19 @@ ResReadCapacitor(int argc,
     ResExtNode	*node1, *node2;
 
     entry1 = HashFind(&ResNodeTable, argv[COUPLETERMINAL1]);
-    node1 = ResInitializeNode(entry1);
+    node1 = ResExtInitNode(entry1);
 
     if (ResOptionsFlags & ResOpt_Signal)
     {
         node1->capacitance += MagAtof(argv[COUPLEVALUE]);
         entry2 = HashFind(&ResNodeTable, argv[COUPLETERMINAL2]);
-        node2 = ResInitializeNode(entry2);
+        node2 = ResExtInitNode(entry2);
         node2->capacitance += MagAtof(argv[COUPLEVALUE]);
         return 0;
     }
 
     entry2 = HashFind(&ResNodeTable, argv[COUPLETERMINAL2]);
-    node2 = ResInitializeNode(entry2);
+    node2 = ResExtInitNode(entry2);
 
     node1->cap_couple += MagAtof(argv[COUPLEVALUE]);
     node2->cap_couple += MagAtof(argv[COUPLEVALUE]);
@@ -612,7 +629,7 @@ ResReadAttribute(ResExtNode *node,
 /*
  *-------------------------------------------------------------------------
  *
- * ResInitializeNode --
+ * ResExtInitNode --
  *	Gets the node corresponding to a given hash table entry.  If no
  *	such node exists, one is created.
  *
@@ -624,7 +641,7 @@ ResReadAttribute(ResExtNode *node,
  */
 
 ResExtNode *
-ResInitializeNode(entry)
+ResExtInitNode(entry)
     HashEntry	*entry;
 {
     ResExtNode	*node;
@@ -638,7 +655,6 @@ ResInitializeNode(entry)
 	node->status = FALSE;
 	node->forward = (ResExtNode *) NULL;
 	node->capacitance = 0;
-	node->cap_vdd = 0;
 	node->cap_couple = 0;
 	node->resistance = 0;
 	node->type = 0;
@@ -649,8 +665,6 @@ ResInitializeNode(entry)
 	node->drivepoint.p_y = INFINITY;
 	node->location.p_x = INFINITY;
 	node->location.p_y = INFINITY;
-	node->rs_sublist[0] = NULL;
-	node->rs_sublist[1] = NULL;
     }
     while (node->status & FORWARD)
     {
